
/*
 * peekc.c -- peek at the next character in a stream
 *
 * $Id$
 */

#include "../h/mh.h"


int
peekc(FILE *ib)
{
    register int c;

    c = getc(ib);
    ungetc(c, ib);

    return c;
}
